@@ -1,5 +1,6 @@
 package Carton::CLI;
 use strict;
+use warnings;
 use Config;
 use Getopt::Long;
 use Path::Tiny;
@@ -387,7 +388,12 @@ sub cmd_exec {
     local $ENV{PERL5LIB} = "$path/lib/perl5";
     local $ENV{PATH} = "$path/bin:$ENV{PATH}";
 
-    $UseSystem ? system(@args) : exec(@args);
+    if ($UseSystem) {
+        system @args;
+    } else {
+        exec @args;
+        exit 127; # command not found
+    }
 }
 
 1;
